@@ -25,14 +25,17 @@ get_release_by_release_date <-
     resource <- '/rest/release'
     resource_urls <- sprintf("%s/%s", resource, release_date)
 
+    get_release <- purrr::slowly(f = get_release, rate = purrr::rate_delay(pause = delay()))
+
     purrr::map(
       resource_urls,
       get_release,
       limit = limit,
       warnings = warnings,
       verbose = verbose,
-      progress_bar = progress_bar
-    ) %>%
+      progress_bar = FALSE,
+      .progress = progress_bar
+    ) |>
       purrr::pmap(dplyr::bind_rows)
 }
 
@@ -119,7 +122,7 @@ get_releases <- function(date = 'latest',
   if (identical(date, 'latest')) {
     tbl <- get_release_current(verbose = verbose,
                                warnings = warnings,
-                               progress_bar = progress_bar) %>%
+                               progress_bar = progress_bar)  |>
       coerce_to_s4_releases()
     return(tbl)
   }
@@ -127,7 +130,7 @@ get_releases <- function(date = 'latest',
   if (identical(date, 'all')) {
     tbl <- get_release_all(verbose = verbose,
                            warnings = warnings,
-                           progress_bar = progress_bar) %>%
+                           progress_bar = progress_bar) |>
       coerce_to_s4_releases()
 
     return(tbl)
@@ -139,7 +142,7 @@ get_releases <- function(date = 'latest',
       verbose = verbose,
       warnings = warnings,
       progress_bar = progress_bar
-    ) %>%
+    ) |>
       coerce_to_s4_releases()
 
     return(tbl)
